@@ -1,13 +1,12 @@
 #ifndef FZ_RTT_HEADER
 #define FZ_RTT_HEADER
 
-#include "socket.h"
+#include <libfilezilla/mutex.hpp>
+#include <libfilezilla/time.hpp>
 
 class CLatencyMeasurement final
 {
 public:
-	CLatencyMeasurement();
-
 	// Returns false if measurement cannot be started due to
 	// a measurement already running
 	bool Start();
@@ -26,7 +25,7 @@ protected:
 	int64_t m_summed_latency{};
 	int m_measurements{};
 
-	mutable fz::mutex m_sync;
+	mutable fz::mutex m_sync{false};
 };
 
 #endif
