@@ -533,16 +533,21 @@ protected:
 		for (;;) {
 #ifdef FZ_WINDOWS
 			int wait_events = FD_CLOSE;
-			if (m_waiting & WAIT_CONNECT)
+			if (m_waiting & WAIT_CONNECT) {
 				wait_events |= FD_CONNECT;
-			if (m_waiting & WAIT_READ)
+			}
+			if (m_waiting & WAIT_READ) {
 				wait_events |= FD_READ;
-			if (m_waiting & WAIT_WRITE)
+			}
+			if (m_waiting & WAIT_WRITE) {
 				wait_events |= FD_WRITE;
-			if (m_waiting & WAIT_ACCEPT)
+			}
+			if (m_waiting & WAIT_ACCEPT) {
 				wait_events |= FD_ACCEPT;
-			if (m_waiting & WAIT_CLOSE)
+			}
+			if (m_waiting & WAIT_CLOSE) {
 				wait_events |= FD_CLOSE;
+			}
 			WSAEventSelect(m_pSocket->m_fd, m_sync_event, wait_events);
 			l.unlock();
 			WSAWaitForMultipleEvents(1, &m_sync_event, false, WSA_INFINITE, false);
@@ -604,11 +609,13 @@ protected:
 			FD_ZERO(&writefds);
 
 			FD_SET(m_pipe[0], &readfds);
-			if (!(m_waiting & WAIT_CONNECT))
+			if (!(m_waiting & WAIT_CONNECT)) {
 				FD_SET(m_pSocket->m_fd, &readfds);
+			}
 
-			if (m_waiting & (WAIT_WRITE | WAIT_CONNECT))
+			if (m_waiting & (WAIT_WRITE | WAIT_CONNECT)) {
 				FD_SET(m_pSocket->m_fd, &writefds);
+			}
 
 			int maxfd = std::max(m_pipe[0], m_pSocket->m_fd) + 1;
 
@@ -628,13 +635,15 @@ protected:
 				return false;
 			}
 
-			if (!res)
+			if (!res) {
 				continue;
+			}
 			if (res == -1) {
 				res = errno;
 
-				if (res == EINTR)
+				if (res == EINTR) {
 					continue;
+				}
 
 				return false;
 			}
@@ -643,9 +652,10 @@ protected:
 				if (FD_ISSET(m_pSocket->m_fd, &writefds)) {
 					int error;
 					socklen_t len = sizeof(error);
-					int res = getsockopt(m_pSocket->m_fd, SOL_SOCKET, SO_ERROR, &error, &len);
-					if (res)
+					int getsockopt_res = getsockopt(m_pSocket->m_fd, SOL_SOCKET, SO_ERROR, &error, &len);
+					if (getsockopt_res) {
 						error = errno;
+					}
 					m_triggered |= WAIT_CONNECT;
 					m_triggered_errors[0] = error;
 					m_waiting &= ~WAIT_CONNECT;
@@ -670,8 +680,9 @@ protected:
 				}
 			}
 
-			if (m_triggered || !m_waiting)
+			if (m_triggered || !m_waiting) {
 				return true;
+			}
 #endif
 		}
 	}
@@ -846,8 +857,9 @@ CSocket::CSocket(fz::thread_pool & pool, fz::event_handler* pEvtHandler)
 
 CSocket::~CSocket()
 {
-	if (m_state != none)
+	if (m_state != none) {
 		Close();
+	}
 
 	if (m_pSocketThread) {
 		fz::scoped_lock l(m_pSocketThread->m_sync);
@@ -857,8 +869,9 @@ CSocket::~CSocket()
 
 void CSocket::DetachThread(fz::scoped_lock & l)
 {
-	if (!m_pSocketThread)
+	if (!m_pSocketThread) {
 		return;
+	}
 
 	m_pSocketThread->SetSocket(0, l);
 	if (m_pSocketThread->m_finished) {
@@ -1554,7 +1567,7 @@ int CSocket::DoSetFlags(int fd, int flags, int flags_mask, fz::duration const& k
 #if FZ_WINDOWS
 		tcp_keepalive v{};
 		v.onoff = (flags & flag_keepalive) ? 1 : 0;
-		v.keepalivetime = keepalive_interval.get_milliseconds();
+		v.keepalivetime = static_cast<ULONG>(keepalive_interval.get_milliseconds());
 		v.keepaliveinterval = 1000;
 		DWORD tmp{};
 		int res = WSAIoctl(fd, SIO_KEEPALIVE_VALS, &v, sizeof(v), 0, 0, &tmp, 0, 0);
@@ -1614,7 +1627,7 @@ int CSocket::GetIdealSendBufferSize()
 		// enabled unless an application sets the SO_SNDBUF socket option on
 		// the stream socket"
 		//
-		// Guess what: It doesn't do it by itself. Programs need to 
+		// Guess what: It doesn't do it by itself. Programs need to
 		// periodically and manually update SO_SNDBUF based on what
 		// SIO_IDEAL_SEND_BACKLOG_QUERY returns.
 #ifndef SIO_IDEAL_SEND_BACKLOG_QUERY
