@@ -1,5 +1,5 @@
-#ifndef __COMMANDS_H__
-#define __COMMANDS_H__
+#ifndef FILEZILLA_ENGINE_COMMANDS_HEADER
+#define FILEZILLA_ENGINE_COMMANDS_HEADER
 
 // See below for actual commands and their parameters
 
@@ -21,7 +21,9 @@ enum class Command
 
 	// Only used internally
 	cwd,
-	rawtransfer
+	private1,
+	private2,
+	private3
 };
 
 // Reply codes
@@ -44,7 +46,9 @@ enum class Command
 #define FZ_REPLY_TIMEOUT		(0x0800 | FZ_REPLY_ERROR)
 #define FZ_REPLY_NOTSUPPORTED	(0x1000 | FZ_REPLY_ERROR) // Will be returned if command not supported by that protocol
 #define FZ_REPLY_WRITEFAILED	(0x2000 | FZ_REPLY_ERROR) // Happens if local file could not be written during transfer
-#define FZ_REPLY_LINKNOTDIR		(0x4000)
+#define FZ_REPLY_LINKNOTDIR		(0x4000 | FZ_REPLY_ERROR)
+
+#define FZ_REPLY_CONTINUE 0x8000 // Used internally
 
 // --------------- //
 // Actual commands //
@@ -126,10 +130,10 @@ class CListCommand final : public CCommandHelper<CListCommand, Command::list>
 	// directories.
 public:
 	explicit CListCommand(int flags = 0);
-	explicit CListCommand(CServerPath path, wxString subDir = wxString(), int flags = 0);
+	explicit CListCommand(CServerPath path, std::wstring const& subDir = std::wstring(), int flags = 0);
 
 	CServerPath GetPath() const;
-	wxString GetSubDir() const;
+	std::wstring GetSubDir() const;
 
 	int GetFlags() const { return m_flags; }
 
@@ -137,7 +141,7 @@ public:
 
 protected:
 	CServerPath const m_path;
-	wxString const m_subDir;
+	std::wstring const m_subDir;
 	int const m_flags;
 };
 
@@ -177,14 +181,14 @@ protected:
 class CRawCommand final : public CCommandHelper<CRawCommand, Command::raw>
 {
 public:
-	explicit CRawCommand(const wxString &command);
+	explicit CRawCommand(std::wstring const& command);
 
-	wxString GetCommand() const;
+	std::wstring GetCommand() const;
 
 	bool valid() const { return !m_command.empty(); }
 
 protected:
-	wxString m_command;
+	std::wstring m_command;
 };
 
 class CDeleteCommand final : public CCommandHelper<CDeleteCommand, Command::del>
@@ -207,16 +211,16 @@ class CRemoveDirCommand final : public CCommandHelper<CRemoveDirCommand, Command
 public:
 	// Directories can either be given as absolute path or as
 	// pair of an absolute path and the very last path segments.
-	CRemoveDirCommand(CServerPath const& path, wxString const& subdDir);
+	CRemoveDirCommand(CServerPath const& path, std::wstring const& subdDir);
 
 	CServerPath GetPath() const { return m_path; }
-	wxString GetSubDir() const { return m_subDir; }
+	std::wstring GetSubDir() const { return m_subDir; }
 
 	bool valid() const;
 
 protected:
 	CServerPath const m_path;
-	wxString const m_subDir;
+	std::wstring const m_subDir;
 };
 
 class CMkdirCommand final : public CCommandHelper<CMkdirCommand, Command::mkdir>
@@ -235,21 +239,21 @@ protected:
 class CRenameCommand final : public CCommandHelper<CRenameCommand, Command::rename>
 {
 public:
-	CRenameCommand(CServerPath const& fromPath, wxString const& fromFile,
-				   CServerPath const& toPath, wxString const& toFile);
+	CRenameCommand(CServerPath const& fromPath, std::wstring const& fromFile,
+				   CServerPath const& toPath, std::wstring const& toFile);
 
 	CServerPath GetFromPath() const { return m_fromPath; }
 	CServerPath GetToPath() const { return m_toPath; }
-	wxString GetFromFile() const { return m_fromFile; }
-	wxString GetToFile() const { return m_toFile; }
+	std::wstring GetFromFile() const { return m_fromFile; }
+	std::wstring GetToFile() const { return m_toFile; }
 
 	bool valid() const;
 
 protected:
 	CServerPath const m_fromPath;
 	CServerPath const m_toPath;
-	wxString const m_fromFile;
-	wxString const m_toFile;
+	std::wstring const m_fromFile;
+	std::wstring const m_toFile;
 };
 
 class CChmodCommand final : public CCommandHelper<CChmodCommand, Command::chmod>
@@ -258,18 +262,18 @@ public:
 	// The permission string should be given in a format understandable by the server.
 	// Most likely it's the defaut octal representation used by the unix chmod command,
 	// i.e. chmod 755 foo.bar
-	CChmodCommand(const CServerPath& path, const wxString& file, const wxString& permission);
+	CChmodCommand(CServerPath const& path, std::wstring const& file, std::wstring const& permission);
 
 	CServerPath GetPath() const { return m_path; }
-	wxString GetFile() const { return m_file; }
-	wxString GetPermission() const { return m_permission; }
+	std::wstring GetFile() const { return m_file; }
+	std::wstring GetPermission() const { return m_permission; }
 
 	bool valid() const;
 
 protected:
 	CServerPath const m_path;
-	wxString const m_file;
-	wxString const m_permission;
+	std::wstring const m_file;
+	std::wstring const m_permission;
 };
 
 #endif
