@@ -14,6 +14,7 @@
 #include "context_control.h"
 #include "defaultfileexistsdlg.h"
 #include "edithandler.h"
+#include "encoding_converter.h"
 #include "export.h"
 #include "filelist_statusbar.h"
 #include "filezillaapp.h"
@@ -183,7 +184,7 @@ BEGIN_EVENT_TABLE(CMainFrame, wxNavigationEnabled<wxFrame>)
 	EVT_MENU(XRCID("ID_MENU_FILE_CLOSETAB"), CMainFrame::OnMenuCloseTab)
 END_EVENT_TABLE()
 
-class CMainFrameStateEventHandler : public CGlobalStateEventHandler
+class CMainFrameStateEventHandler final : public CGlobalStateEventHandler
 {
 public:
 	CMainFrameStateEventHandler(CMainFrame* pMainFrame)
@@ -249,7 +250,7 @@ protected:
 };
 
 CMainFrame::CMainFrame()
-	: m_engineContext(*COptions::Get())
+	: m_engineContext(*COptions::Get(), CustomEncodingConverter::Get())
 	, m_comparisonToggleAcceleratorId(wxNewId())
 {
 	m_pActivityLed[0] = m_pActivityLed[1] = 0;
@@ -338,10 +339,12 @@ CMainFrame::CMainFrame()
 	m_pQueueLogSplitter->SetSashGravity(0.5);
 	m_pQueuePane = new CQueue(m_pQueueLogSplitter, this, m_pAsyncRequestQueue);
 
-	if (message_log_position == 1)
+	if (message_log_position == 1) {
 		m_pStatusView = new CStatusView(m_pQueueLogSplitter, -1);
-	else
+	}
+	else {
 		m_pStatusView = new CStatusView(m_pTopSplitter, -1);
+	}
 
 	m_pQueueView = m_pQueuePane->GetQueueView();
 
@@ -755,8 +758,9 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		}
 	}
 	else if (event.GetId() == XRCID("ID_VIEW_QUICKCONNECT")) {
-		if (!m_pQuickconnectBar)
+		if (!m_pQuickconnectBar) {
 			CreateQuickconnectBar();
+		}
 		else {
 			m_pQuickconnectBar->Destroy();
 			m_pQuickconnectBar = 0;
@@ -780,7 +784,7 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		if (!pState) {
 			return;
 		}
-		
+
 		Site const old_site = pState->GetSite();
 		std::wstring sitePath = old_site.m_path;
 
@@ -804,11 +808,10 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 				std::unique_ptr<Site> site = CSiteManager::GetSiteByPath(sitePath, false).first;
 				if (site) {
 					for (int i = 0; i < m_pContextControl->GetTabCount(); ++i) {
-						CContextControl::_context_controls *controls = m_pContextControl->GetControlsFromTabIndex(i);
-						if (!controls) {
-							continue;
+						CContextControl::_context_controls *tab_controls = m_pContextControl->GetControlsFromTabIndex(i);
+						if (tab_controls) {
+							tab_controls->pState->UpdateSite(old_site.m_path, *site);
 						}
-						controls->pState->UpdateSite(old_site.m_path, *site);
 					}
 				}
 			}
@@ -887,14 +890,16 @@ void CMainFrame::DoOnEngineEvent(CFileZillaEngine* engine)
 	const std::vector<CState*> *pStates = CContextManager::Get()->GetAllStates();
 	CState* pState = 0;
 	for (std::vector<CState*>::const_iterator iter = pStates->begin(); iter != pStates->end(); ++iter) {
-		if ((*iter)->m_pEngine != engine)
+		if ((*iter)->m_pEngine != engine) {
 			continue;
+		}
 
 		pState = *iter;
 		break;
 	}
-	if (!pState)
+	if (!pState) {
 		return;
+	}
 
 	std::unique_ptr<CNotification> pNotification = pState->m_pEngine->GetNextNotification();
 	while (pNotification) {
@@ -968,8 +973,9 @@ void CMainFrame::OnUpdateLedTooltip(wxCommandEvent&)
 	wxFileOffset uploadSpeed = m_pQueueView ? m_pQueueView->GetCurrentUploadSpeed() : 0;
 
 	CSizeFormat::_format format = static_cast<CSizeFormat::_format>(COptions::Get()->GetOptionVal(OPTION_SIZE_FORMAT));
-	if (format == CSizeFormat::bytes)
+	if (format == CSizeFormat::bytes) {
 		format = CSizeFormat::iec;
+	}
 
 	const wxString downloadSpeedStr = CSizeFormat::Format(downloadSpeed, true, format,
 														  COptions::Get()->GetOptionVal(OPTION_SIZE_USETHOUSANDSEP) != 0,
@@ -986,11 +992,11 @@ void CMainFrame::OnUpdateLedTooltip(wxCommandEvent&)
 bool CMainFrame::CreateMainToolBar()
 {
 	wxGetApp().AddStartupProfileRecord("CMainFrame::CreateMainToolBar");
-	if (m_pToolBar)
-	{
+	if (m_pToolBar) {
 #ifdef __WXMAC__
-		if (m_pToolBar)
+		if (m_pToolBar) {
 			COptions::Get()->SetOption(OPTION_TOOLBAR_HIDDEN, m_pToolBar->IsShown() ? 0 : 1);
+		}
 #endif
 		SetToolBar(0);
 		delete m_pToolBar;
@@ -998,20 +1004,28 @@ bool CMainFrame::CreateMainToolBar()
 	}
 
 #ifndef __WXMAC__
-	if (COptions::Get()->GetOptionVal(OPTION_TOOLBAR_HIDDEN) != 0)
+	if (COptions::Get()->GetOptionVal(OPTION_TOOLBAR_HIDDEN) != 0) {
 		return true;
+	}
 #endif
 
 	m_pToolBar = CToolBar::Load(this);
-	if (!m_pToolBar)
-	{
+	if (!m_pToolBar) {
 		wxLogError(_("Cannot load toolbar from resource file"));
 		return false;
 	}
 	SetToolBar(m_pToolBar);
 
-	if (m_pQuickconnectBar)
+#ifdef __WXMAC__
+	if (COptions::Get()->GetOptionVal(OPTION_TOOLBAR_HIDDEN) != 0) {
+		m_pToolBar->Show(false);
+	}
+#endif
+
+
+	if (m_pQuickconnectBar) {
 		m_pQuickconnectBar->Refresh();
+	}
 
 	return true;
 }
@@ -1189,19 +1203,22 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 		RememberSplitterPositions();
 
 #ifdef __WXMAC__
-		if (m_pToolBar)
+		if (m_pToolBar) {
 			COptions::Get()->SetOption(OPTION_TOOLBAR_HIDDEN, m_pToolBar->IsShown() ? 0 : 1);
+		}
 #endif
 		m_bQuit = true;
 	}
 
 	Show(false);
-	if (!CloseDialogsAndQuit(event))
+	if (!CloseDialogsAndQuit(event)) {
 		return;
+	}
 
 	// Getting deleted by wxWidgets
-	for (int i = 0; i < 2; i++)
+	for (int i = 0; i < 2; ++i) {
 		m_pActivityLed[i] = 0;
+	}
 	m_pStatusBar = 0;
 	m_pMenuBar = 0;
 	m_pToolBar = 0;
@@ -1211,7 +1228,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 	m_pStateEventHandler = 0;
 
 	if (m_pQueueView && !m_pQueueView->Quit()) {
-		if( event.CanVeto() ) {
+		if (event.CanVeto()) {
 			event.Veto();
 		}
 		return;
@@ -1240,7 +1257,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 	}
 
 	if (!res) {
-		if( event.CanVeto() ) {
+		if (event.CanVeto()) {
 			event.Veto();
 		}
 		return;
@@ -2600,12 +2617,14 @@ void CMainFrame::OnToggleToolBar(wxCommandEvent& event)
 {
 	COptions::Get()->SetOption(OPTION_TOOLBAR_HIDDEN, event.IsChecked() ? 0 : 1);
 #ifdef __WXMAC__
-	if (m_pToolBar)
-		m_pToolBar->Show( event.IsChecked() );
+	if (m_pToolBar) {
+		m_pToolBar->Show(event.IsChecked());
+	}
 #else
 	CreateMainToolBar();
-	if (m_pToolBar)
+	if (m_pToolBar) {
 		m_pToolBar->UpdateToolbarState();
+	}
 	HandleResize();
 #endif
 }
@@ -2630,6 +2649,7 @@ void CMainFrame::SetupKeyboardAccelerators()
 	for (int i = 0; i < 10; i++) {
 		tab_hotkey_ids[i] = wxNewId();
 		entries.emplace_back(wxACCEL_CMD, (int)'0' + i, tab_hotkey_ids[i]);
+		entries.emplace_back(wxACCEL_ALT, (int)'0' + i, tab_hotkey_ids[i]);
 	}
 	entries.emplace_back(wxACCEL_CMD | wxACCEL_SHIFT, 'O', m_comparisonToggleAcceleratorId);
 	entries.emplace_back(wxACCEL_CMD | wxACCEL_SHIFT, 'I', XRCID("ID_MENU_VIEW_FILTERS"));
